@@ -49,6 +49,11 @@ dictionary_object_destroy (GtkObject *object)
 {
 	GNOMESpellDictionary *dictionary = GNOME_SPELL_DICTIONARY (object);
 
+	if (dictionary->manager)
+		delete_pspell_manager (dictionary->manager);
+	if (dictionary->config)
+		delete_pspell_config (dictionary->config);
+
 	GTK_OBJECT_CLASS (dictionary_parent_class)->destroy (object);
 }
 
@@ -269,8 +274,8 @@ gnome_spell_dictionary_get_type (void)
 	return type;
 }
 
-GNOMESpellDictionary *
-dictionary_construct (GNOMESpellDictionary *dictionary, GNOME_Spell_Dictionary corba_dictionary)
+BonoboObject *
+dictionary_construct (BonoboObject *dictionary, GNOME_Spell_Dictionary corba_dictionary)
 {
 	CORBA_Environment ev;
 	static int i;
@@ -279,7 +284,7 @@ dictionary_construct (GNOMESpellDictionary *dictionary, GNOME_Spell_Dictionary c
 	g_return_val_if_fail (IS_GNOME_SPELL_DICTIONARY (dictionary), NULL);
 	g_return_val_if_fail (corba_dictionary != CORBA_OBJECT_NIL, NULL);
 
-	if (!bonobo_object_construct (BONOBO_OBJECT (dictionary), (CORBA_Object) corba_dictionary))
+	if (!bonobo_object_construct (dictionary, (CORBA_Object) corba_dictionary))
 		return NULL;
 
 	CORBA_exception_init (&ev);
@@ -316,14 +321,14 @@ create_dictionary (BonoboObject *dictionary)
 	return (GNOME_Spell_Dictionary) bonobo_object_activate_servant (dictionary, servant);
 }
 
-GNOMESpellDictionary *
+BonoboObject *
 gnome_spell_dictionary_new (void)
 {
-	GNOMESpellDictionary *dictionary;
+	BonoboObject *dictionary;
 	GNOME_Spell_Dictionary corba_dictionary;
 
               dictionary = gtk_type_new (gnome_spell_dictionary_get_type ());
-	corba_dictionary = create_dictionary (BONOBO_OBJECT (dictionary));
+	corba_dictionary = create_dictionary (dictionary);
 
 	if (corba_dictionary == CORBA_OBJECT_NIL) {
 		bonobo_object_unref (BONOBO_OBJECT (dictionary));
